__code__='Gat=(s)6@U\'RuIZTe-\\a;IF;p4;_9\\Bb\'$$:"(qYKbTX(X<N?l@?]gL?!C7J2Wq\\1Q-)lkg+W?(p6Y0[ZVAjk%B44BcG$pbq=<m!&^:1/T^*E*MLR&4/JnLN7KEea(-!?o?mIuE3!R*bqusA,8A?LE"#pP<!^$QE&%DVL#^@-S*8j>;k5d49/cgD0\\.!ToE!>_Di+9\\SJ=cgJ"oK)(1VddVf)\\)@]Kn(b?8\\/:d@]%K&)qb?1^C>*$D[cE%Z[#$?N1JPQO^YRFr0WUQ9$3!2dt)4P&(t$@2OjD,*,I0IV#"X-l`9[UpWPo8#7$<VVVY,UrPdURGp%R*1iUoX33IdQV5,VJBMl"TIoA)P<h`InH<s/SnVBMg4?"\'j:CRYJh)1!5btj4-"5]$V&7u?JrOD=qjY8hCR]0Q1hS6\'80)HI$r<sY8KmJ;;9a.XVD?RPk:05LBu.\'$P&9M22=+mZm$J!:>A9RDfjHe>6r()r^Urqtn5_W)ME99]a65K33bBm8d)ur:G+LKj0lJST.$hi8Y[g*SchjPR?42?A*6THYMtUSLTh5%LS:,d%_PCAErj,R)i,.%L,pc\\^IY6RcEp[XQfRa4iAE==,"1(atqb6.?dXJ^fDYVN_DHs]FS&CF_$]/c(88tB\\CjTdOY1EE0S^,\'fJZ%jF&oMtl2YPo=\\aLJu`nl03Qr(h+l=S2(P<;m!(hNO%8N<TD<2WF_Xg`2FPf\\&"jF^T@j3D1`B_T*sA+1T#qbe01<G.`#,gkn$$1#=9H.#O.n/am[J&C\'JC/Q\'MmA?B,n!35YU2tCNU><&8?CAOa2s4nfGN\\B7qQ8WQrk[mu+0)1#B).,NVl>t3-!=8^n+X!\\MJhE.Y>:!XS6o8O/DTO!K^APIM8j417XK-d;cgV:oQun-ILGg1]NpbLIWs&<bcG"[G<:`sM&!gEp)C.nA:)k9pVPo"A7SZ@&)A%AQIs&DF^O9L[T,7*rgG0@F6e&sChJ+t<J/\\An)804T[(%Q6eb?q^H^2dWl\'X4V!5+sCD*tEV*&c<-Ds"@X>mH"f3,RmS^;qWcM+4f_tJK6gO^PA\'%0cPjYR`fA]@o6$bNWUj8OnD2[,dF5)!kinl+52IV+c&>;!\\#fNJgoU@gbN<uWZaebBq=.&#`~>'
